@@ -11,7 +11,7 @@ Term::Shell::MultiCmd -  Nested Commands Tree in Shell Interface
 
 =cut
 
-our $VERSION = '2.01';
+our $VERSION = '2.02';
 
 =head1 SYNOPSIS
 
@@ -167,6 +167,7 @@ sub _travela($@) {              # explicit array
 
 sub _travel($$) {
     my ($o, $c) = &_check_pager ; # clear $c pager sign, let cmd know about it.
+    $c = _check_inner_alias($o, $c);
     _travela( $o, _split $o, $c )
 }
 
@@ -746,6 +747,10 @@ sub _help_message {
     my %p = _params "node path full= recursive= tree= ARGV= ARG0=", @_ ;
     my ($h, $p) = @p{'node', 'path'} ;
     $p =~ s/^\s*(.*?)\s*$/$1/ ;
+    sub _align2($$) {
+        my ($a, $b) = @_;
+        _say $a, (' ' x (20 - length $a)), ': ', $b
+    }
 
     if ('ARRAY' eq ref $h) {    # simple command, full help
         my $help = $h->[0] ;
@@ -775,10 +780,10 @@ sub _help_message {
 
         for my $k (sort keys %$h) {
             next if $k eq $dlm ;
-            _say _join($o, $p, $k), ": \t",
-              (('ARRAY' eq ref $h->{$k}) ?
-               ($h->{$k}[0]  || 'a command' ) :
-               ($h->{$k}{$dlm} || 'a prefix' ) ) =~ /^(.*)$/m ;
+            my ($l) = (('ARRAY' eq ref $h->{$k}) ?
+                       ($h->{$k}[0]    || 'a command') :
+                       ($h->{$k}{$dlm} || 'a prefix' ) ) =~ /^(.*)$/m ;
+            _align2 _join($o, $p, $k), $l;
         }
     }
     else {                      # just show the prefix with optional help
@@ -870,6 +875,24 @@ sub _check_pager {
     ($o, $c)
 }
 
+sub _check_inner_alias {
+    my ($o, $c) = @_ ;
+    my $d = $o->{delimiterRE};
+    my $r = $o->{root} || $o->{cmds};
+    if ($o->{root_cmd} and
+        not exists $r->{cd} ) {
+
+        return _join $o, $o->{root_cmd}, '-clear'   if $c =~ /^cd$/;
+        return _join $o, $o->{root_cmd}, '-set', $1 if $c =~ /^cd$d(.*)$/;
+    }
+    if ($o->{help_cmd} and
+        not exists $r->{ls} ) {
+        return _join $o, $o->{help_cmd}     if $c =~ /^ls$/;
+        return _join $o, $o->{help_cmd}, $1 if $c =~ /^ls$d(.*)/ ;
+    }
+    $c
+}
+
 =head2 cmd
 
  $cli -> cmd ( "help -tree" ) ;
@@ -903,7 +926,7 @@ sub cmd {
 sub _cmd {
     my ($o, $cmd, $path, @args) = @_ ;
     return print $cmd unless ref $cmd ;
-    return $o->{empty_cmd}->() if $o->{empty_cmd} and $cmd eq $o->{cmds} and 0 == length join '', @args;
+    return $o->{empty_cmd}->() if $o->{empty_cmd} and $cmd eq ($o -> {root} || $o->{cmds}) and 0 == length join '', @args;
     return _say "No such command or prefix: " . _join $o, @args if $cmd eq $o->{cmds} ;
     return _help_message($o, -node => $cmd, -path => $path) unless 'ARRAY' eq ref $cmd ; # help message
     my %p = _options $cmd->[3] || '', @args ;
